@@ -6,7 +6,7 @@ use 5.010;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 use Carp qw(confess cluck);
 use Encode qw(encode decode);
@@ -127,6 +127,13 @@ sub new {
 
 	$self->{xml} = $response->decoded_content;
 
+	if ( not $self->{xml} ) {
+
+		# LibXML doesn't like empty documents
+		$self->{errstr} = 'Server returned nothing (empty result)';
+		return $self;
+	}
+
 	$self->{tree} = XML::LibXML->load_xml(
 		string => $self->{xml},
 	);
@@ -293,6 +300,7 @@ sub lines {
 		my $direction  = $e->getAttribute('direction');
 		my $valid      = $e->getAttribute('valid');
 		my $type       = $e_info->getAttribute('name');
+		my $mot        = $e->getAttribute('motType');
 		my $route      = ( $e_route ? $e_route->textContent : undef );
 		my $operator   = ( $e_oper ? $e_oper->textContent : undef );
 		my $identifier = $e->getAttribute('stateless');
@@ -304,6 +312,7 @@ sub lines {
 				direction  => decode( 'UTF-8', $direction ),
 				valid      => $valid,
 				type       => decode( 'UTF-8', $type ),
+				mot        => $mot,
 				route      => decode( 'UTF-8', $route ),
 				operator   => decode( 'UTF-8', $operator ),
 				identifier => $identifier,
@@ -408,6 +417,7 @@ sub results {
 		my $countdown     = $e->getAttribute('countdown');
 		my $delay         = $e_info->getAttribute('delay');
 		my $type          = $e_info->getAttribute('name');
+		my $mot           = $e_line->getAttribute('motType');
 
 		my $platform_is_db = 0;
 
@@ -467,6 +477,7 @@ sub results {
 				sched_date    => $date,
 				sched_time    => $time,
 				type          => $type,
+				mot           => $mot,
 				prev_route    => \@prev_route,
 				next_route    => \@next_route,
 			)
@@ -482,6 +493,69 @@ sub results {
 	return @results;
 }
 
+# static
+sub get_efa_urls {
+	return (
+		{
+			url       => 'http://www.ding.eu/ding3/XSLT_DM_REQUEST',
+			name      => 'Donau-Iller Nahverkehrsverbund',
+			shortname => 'DING',
+		},
+		{
+			url       => 'http://efa.ivb.at/ivb/XSLT_DM_REQUEST',
+			name      => 'Innsbrucker Verkehrsbetriebe',
+			shortname => 'IVB',
+		},
+		{
+			url       => 'http://efa.svv-info.at/sbs/XSLT_DM_REQUEST',
+			name      => 'Salzburger Verkehrsverbund',
+			shortname => 'SVV',
+		},
+		{
+			url       => 'http://efa.vor.at/wvb/XSLT_DM_REQUEST',
+			name      => 'Verkehrsverbund Ost-Region',
+			shortname => 'VOR',
+		},
+		{
+			url       => 'http://efaneu.vmobil.at/vvv/XSLT_DM_REQUEST',
+			name      => 'Vorarlberger Verkehrsverbund',
+			shortname => 'VVV',
+		},
+
+		# Returns broken Unicode which makes Encode::decode die()
+		#{
+		#	url       => 'http://fahrplan.verbundlinie.at/stv/XSLT_DM_REQUEST',
+		#	name      => 'Verkehrsverbund Steiermark',
+		#	shortname => 'Verbundlinie',
+		#},
+		{
+			url       => 'http://www.linzag.at/static/XSLT_DM_REQUEST',
+			name      => 'Linz AG',
+			shortname => 'LinzAG',
+		},
+		{
+			url       => 'http://212.114.197.7/vgnExt_oeffi/XML_DM_REQUEST',
+			name      => 'Verkehrsverbund Grossraum Nuernberg',
+			shortname => 'VGN',
+		},
+		{
+			url       => 'http://efa.vrr.de/vrr/XSLT_DM_REQUEST',
+			name      => 'Verkehrsverbund Rhein-Ruhr',
+			shortname => 'VRR',
+		},
+		{
+			url       => 'http://app.vrr.de/standard/XML_DM_REQUEST',
+			name      => 'Verkehrsverbund Rhein-Ruhr (alternative)',
+			shortname => 'VRR2',
+		},
+		{
+			url       => 'http://www2.vvs.de/vvs/XSLT_DM_REQUEST',
+			name      => 'Verkehrsverbund Stuttgart',
+			shortname => 'VVS',
+		},
+	);
+}
+
 1;
 
 __END__
@@ -508,7 +582,7 @@ Travel::Status::DE::EFA - unofficial EFA departure monitor
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 DESCRIPTION
 
@@ -594,6 +668,21 @@ describing one line servicing the selected station.
 Returns a list of Travel::Status::DE::EFA::Result(3pm) objects, each one describing
 one departure.
 
+=item Travel::Status::DE::EFA::get_efa_urls()
+
+Returns a list of known EFA entry points. Each list element is a hashref with
+the following elements.
+
+=over
+
+=item B<url>: service URL as passed to B<efa_url>
+
+=item B<name>: Name of the entity operating this service
+
+=item B<shortname>: Short name of the entity
+
+=back
+
 =back
 
 =head1 DIAGNOSTICS
