@@ -6,10 +6,15 @@ use 5.010;
 
 use parent 'Class::Accessor';
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 Travel::Status::DE::EFA::Line->mk_ro_accessors(
-	qw(direction name operator route type valid));
+	qw(direction mot name operator route type valid));
+
+my @mot_mapping = qw{
+  zug s-bahn u-bahn stadtbahn tram stadtbus regionalbus
+  schnellbus seilbahn schiff ast sonstige
+};
 
 sub new {
 	my ( $obj, %conf ) = @_;
@@ -19,6 +24,12 @@ sub new {
 	return bless( $ref, $obj );
 }
 
+sub mot_name {
+	my ($self) = @_;
+
+	return $mot_mapping[ $self->{mot} ] // 'sonstige';
+}
+
 sub TO_JSON {
 	my ($self) = @_;
 
@@ -46,7 +57,7 @@ requested station
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 DESCRIPTION
 
@@ -65,6 +76,16 @@ per actual line.
 
 Direction of the line.  Name of either the destination stop or one on the way.
 
+=item $line->mot
+
+Returns the "mode of transport" number for this line. This is usually an
+integer between 0 and 11.
+
+=item $line->mot_name
+
+Returns the "mode of transport" for this line, for instance "zug", "s-bahn",
+"tram" or "sonstige".
+
 =item $line->name
 
 Name of the line, e.g. "U11", "SB15", "107".
