@@ -8,13 +8,18 @@ no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
 use parent 'Class::Accessor';
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 Travel::Status::DE::EFA::Result->mk_ro_accessors(
 	qw(countdown date delay destination is_cancelled info key line lineref
-	  platform platform_db platform_name sched_date sched_time time type)
+	  mot platform platform_db platform_name sched_date sched_time time type)
 );
 
+my @mot_mapping = qw{
+  zug s-bahn u-bahn stadtbahn tram stadtbus regionalbus
+  schnellbus seilbahn schiff ast sonstige
+};
+
 sub new {
 	my ( $obj, %conf ) = @_;
 
@@ -31,6 +36,12 @@ sub new {
 	return bless( $ref, $obj );
 }
 
+sub mot_name {
+	my ($self) = @_;
+
+	return $mot_mapping[ $self->{mot} ] // 'sonstige';
+}
+
 sub route_pre {
 	my ($self) = @_;
 
@@ -124,7 +135,7 @@ departure received by Travel::Status::DE::EFA
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 DESCRIPTION
 
@@ -187,6 +198,16 @@ The name/number of the line.
 Travel::Status::DE::EFA::Line(3pm) object describing the departing line in
 detail.
 
+=item $departure->mot
+
+Returns the "mode of transport" number. This is usually an integer between 0
+and 11.
+
+=item $departure->mot_name
+
+Returns the "mode of transport", for instance "zug", "s-bahn", "tram" or
+"sonstige".
+
 =item $departure->platform
 
 Departure platform number (may not be a number).
